#! /usr/bin/env node
import yargs from 'yargs';

import exceptionHandler from './handler/exception';
import lookupHandler from './handler/lookup';
import translationHandler from './handler/translation';
import chatHandler from './handler/chat';
import pingHandler from './handler/ping';
import tcpingHandler from './handler/tcping';

exceptionHandler(() => {
  const { argv }: { argv: any } = yargs
    .command(['translate <text>', 't'], 'Translation module.', {
      source: {
        description: 'Source language for recognization.',
        alias: 's',
        type: 'string',
      },
      target: {
        description: 'Target language for translation.',
        alias: 't',
        type: 'string',
      },
    })
    .command(['chat <content>', 'c'], 'ChatGPT.')
    .command(['lookup <domain>', 'l'], 'DNS lookup module.')
    .command(['ping <ip>', 'p'], 'Ping IP or host module.')
    .command(['tcping <host> <port>', 'tcp'], 'Ping IP or host port module.')
    .help()
    .alias('h', 'help');

  if (['translate', 't'].includes(argv._[0]) && argv.text) {
    translationHandler({
      text: argv.text,
      source: argv.source,
      target: argv.target,
    });
  } else if (['chat', 'c'].includes(argv._[0]) && argv.content) {
    chatHandler({
      content: argv.content,
    });
  } else if (['lookup', 'l'].includes(argv._[0]) && argv.domain) {
    lookupHandler(argv.domain);
  } else if (['ping', 'p'].includes(argv._[0]) && argv.ip) {
    pingHandler(argv.ip);
  } else if (['tcping', 'tcp'].includes(argv._[0]) && argv.host && argv.port) {
    tcpingHandler({
      host: argv.host,
      port: argv.port,
    });
  } else {
    throw new Error('SHOW_HELP_ERROR');
  }
});
